Notebooks
========================================================================================

.. toctree::

    Intro <notebooks/intro>
    Building a list of onesources <notebooks/Building_list_of_onesources>
    Example of usage of magSvc <notebooks/Example_of_usage_of_magSvc>
    Example full run <notebooks/example_full_run>
    Examples <notebooks/examples>
    Testing fit of one object of the catalogue <notebooks/Testing_fit_of_one_object_of_the_catalogue>
